#!/usr/bin/env node
import { defineAdderOptions, defineAdderConfig, generateAdderInfo, categories, defineAdderTests, defineAdderChecks, defineAdder } from '@svelte-add/core';

var name = "@svelte-add/bootstrap";
var version = "1.0.14";
var bin = "build/index.js";
var type = "module";
var license = "MIT";
var dependencies = {
	"@svelte-add/core": "workspace:*"
};
var bugs = "https://github.com/svelte-add/svelte-add/issues";
var repository = {
	type: "git",
	url: "https://github.com/svelte-add/svelte-add/tree/main/adders/bootstrap"
};
var keywords = [
	"bootstrap",
	"css",
	"sass",
	"scss",
	"svelte",
	"kit",
	"svelte-kit"
];
var pkg = {
	name: name,
	version: version,
	bin: bin,
	type: type,
	license: license,
	dependencies: dependencies,
	bugs: bugs,
	repository: repository,
	keywords: keywords
};

const options = defineAdderOptions({
  useSass: {
    question: "Do you want to use sass? (css = faster, sass = better customization)",
    type: "boolean",
    default: false
  },
  addJavaScript: {
    question: "Do you want to add JavaScript (required for some components like dropdowns)?",
    type: "boolean",
    default: false
  }
});

const adder = defineAdderConfig({
  metadata: {
    ...generateAdderInfo(pkg),
    name: "Bootstrap",
    description: "Build fast, responsive sites with Bootstrap",
    category: categories.css,
    environments: { kit: true, svelte: true },
    website: {
      logo: "./bootstrap.svg",
      keywords: ["bootstrap", "css", "sass", "scss"],
      documentation: "https://getbootstrap.com/docs/"
    }
  },
  options,
  integrationType: "inline",
  packages: [
    { name: "bootstrap", version: "^5.3.3", dev: true },
    { name: "@popperjs/core", version: "^2.11.8", dev: true, condition: ({ options: options2 }) => options2.addJavaScript },
    { name: "sass", version: "^1.77.5", dev: true, condition: ({ options: options2 }) => options2.useSass }
  ],
  files: [
    {
      name: () => "src/app.scss",
      contentType: "css",
      condition: ({ options: options2 }) => options2.useSass,
      content: ({ ast, addAtRule, addComment, addDeclaration }) => {
        const baseImport = (component) => `"bootstrap/scss/${component}"`;
        const importRule = "import";
        addComment(ast, "1. Include functions first (so you can manipulate colors, SVGs, calc, etc)");
        addAtRule(ast, importRule, baseImport("functions"), true);
        addComment(ast, "2. Include any default variable overrides here");
        addDeclaration(ast, "$body-bg", "$background");
        addComment(
          ast,
          "3. Include remainder of required Bootstrap stylesheets (including any separate color mode stylesheets)"
        );
        addAtRule(ast, importRule, baseImport("variables"), true);
        addAtRule(ast, importRule, baseImport("variables-dark"), true);
        addComment(ast, "4. Include any default map overrides here");
        addComment(ast, "5. Include remainder of required parts");
        addAtRule(ast, importRule, baseImport("maps"), true);
        addAtRule(ast, importRule, baseImport("mixins"), true);
        addAtRule(ast, importRule, baseImport("root"), true);
        addComment(ast, "6. Optionally include any other parts as needed");
        addAtRule(ast, importRule, baseImport("utilities"), true);
        addAtRule(ast, importRule, baseImport("reboot"), true);
        addAtRule(ast, importRule, baseImport("type"), true);
        addAtRule(ast, importRule, baseImport("helpers"), true);
        addAtRule(ast, importRule, baseImport("buttons"), true);
        addComment(
          ast,
          "7. Optionally include utilities API last to generate classes based on the Sass map in `_utilities.scss`"
        );
        addAtRule(ast, importRule, baseImport("utilities/api"), true);
        addComment(ast, "Add additional custom code here");
      }
    },
    {
      name: () => "src/variables.scss",
      contentType: "css",
      condition: ({ options: options2 }) => options2.useSass,
      content: ({ ast, addDeclaration, addComment }) => {
        addComment(ast, "Set your brand colors");
        addDeclaration(ast, "$background", "lightgrey");
      }
    },
    {
      name: () => "src/App.svelte",
      contentType: "svelte",
      condition: ({ kit }) => !kit.installed,
      content: ({ js, html, options: options2 }) => {
        if (options2.useSass) {
          js.imports.addEmpty(js.ast, "./app.scss");
        } else {
          js.imports.addEmpty(js.ast, "bootstrap/dist/css/bootstrap.css");
        }
        if (options2.addJavaScript) {
          addBootstrapJavaScript(js, html, false);
        }
      }
    },
    {
      name: ({ kit }) => `${kit.routesDirectory}/+layout.svelte`,
      contentType: "svelte",
      condition: ({ kit }) => kit.installed,
      content: ({ js, options: options2, html }) => {
        if (options2.useSass) {
          js.imports.addEmpty(js.ast, "../app.scss");
        } else {
          js.imports.addEmpty(js.ast, "bootstrap/dist/css/bootstrap.css");
        }
        const slot = html.element("slot");
        html.ast.childNodes.push(slot);
      }
    },
    {
      name: ({ kit }) => `${kit.routesDirectory}/+layout.svelte`,
      contentType: "svelte",
      condition: ({ kit, options: options2 }) => kit.installed && options2.addJavaScript,
      content: ({ js, html }) => {
        addBootstrapJavaScript(js, html, true);
      }
    },
    {
      name: ({ typescript }) => `vite.config.${typescript.installed ? "ts" : "js"}`,
      contentType: "script",
      condition: ({ options: options2 }) => options2.useSass,
      content: ({ ast, object, common, functions, exports }) => {
        const { value: rootObject } = exports.defaultExport(ast, functions.call("defineConfig", []));
        const param1 = functions.argumentByIndex(rootObject, 0, object.createEmpty());
        const css = object.property(param1, "css", object.createEmpty());
        const preprocessorOptions = object.property(css, "preprocessorOptions", object.createEmpty());
        const scss = object.property(preprocessorOptions, "scss", object.createEmpty());
        const additionalData = object.property(scss, "additionalData", common.createLiteral());
        additionalData.value = `@use "src/variables.scss" as *;`;
      }
    }
  ]
});
function addBootstrapJavaScript(js, html, isKit) {
  js.imports.addNamed(js.ast, "svelte", { onMount: "onMount" });
  if (isKit) {
    js.imports.addNamed(js.ast, "$app/environment", { browser: "browser" });
  }
  const onMountCaller = js.functions.call("onMount", []);
  const onMountExpression = js.common.expressionStatement(onMountCaller);
  js.ast.body.push(onMountExpression);
  const methodBody = js.common.blockStatement();
  const onMountBody = js.functions.arrowFunction(true, methodBody);
  onMountCaller.arguments.push(onMountBody);
  const methodBodyString = `
    ${isKit ? "if (!browser) return;\n" : ""}
    // this is enough for most components
    await import("bootstrap");

    // some components require a bootstrap instance, to fulfil their job. In that case, use this:
    // const bootstrap = await import("bootstrap");
    // sample usage: 
    // const toastBootstrap = bootstrap.Toast.getOrCreateInstance(toastLiveExample)`;
  js.common.addFromString(methodBody, methodBodyString);
  if (isKit) {
    const slot = html.element("slot");
    html.ast.childNodes.push(slot);
  }
}

const tests = defineAdderTests({
  options,
  optionValues: [
    { useSass: false, addJavaScript: true },
    { useSass: true, addJavaScript: true }
  ],
  files: [
    {
      name: ({ kit }) => `${kit.routesDirectory}/+page.svelte`,
      contentType: "svelte",
      condition: ({ kit }) => kit.installed,
      content: ({ html, options: options2 }) => {
        prepareButtonTest(html);
        prepareTypographyTest(html);
        if (options2.addJavaScript) {
          prepareDropdownTest(html);
        }
      }
    },
    {
      name: () => `src/App.svelte`,
      contentType: "svelte",
      condition: ({ kit }) => !kit.installed,
      content: ({ html, options: options2 }) => {
        prepareButtonTest(html);
        prepareTypographyTest(html);
        if (options2.addJavaScript) {
          prepareDropdownTest(html);
        }
      }
    }
  ],
  tests: [
    {
      name: "button properties",
      run: async ({ expectProperty }) => {
        await expectProperty(".btn.btn-primary", "background-color", "rgb(13, 110, 253)");
        await expectProperty(".btn.btn-primary", "padding-top", "6px");
        await expectProperty(".btn.btn-primary", "padding-left", "12px");
        await expectProperty(".btn.btn-success", "background-color", "rgb(25, 135, 84)");
        await expectProperty(".btn.btn-success", "padding-top", "6px");
        await expectProperty(".btn.btn-success", "padding-left", "12px");
      }
    },
    {
      name: "typography properties",
      run: async ({ expectProperty }) => {
        await expectProperty(".h1", "font-size", "40px");
        await expectProperty(".text-decoration-line-through", "text-decoration", "line-through solid rgb(33, 37, 41)");
      }
    },
    {
      name: "dropdown properties",
      run: async ({ click, elementExists }) => {
        await click(".btn.dropdown-toggle");
        await elementExists(".btn.dropdown-toggle.show");
      }
    }
  ]
});
function prepareButtonTest({ ast, addFromRawHtml }) {
  const buttonHtml = `
<button class="btn btn-primary">Test</button>
<button class="btn btn-success">Test</button>
`;
  addFromRawHtml(ast.childNodes, buttonHtml);
}
function prepareTypographyTest({ ast, addFromRawHtml }) {
  const typographyHtml = `
<p class="h1">Test</p>
<p class="text-decoration-line-through">Test</p>
`;
  addFromRawHtml(ast.childNodes, typographyHtml);
}
function prepareDropdownTest({ ast, addFromRawHtml }) {
  const typographyHtml = `
<div class="dropdown">
    <button class="btn btn-secondary dropdown-toggle" type="button" data-bs-toggle="dropdown" aria-expanded="false">
        Dropdown button
    </button>
    <ul class="dropdown-menu">
        <li><a class="dropdown-item" href="#">Action</a></li>
        <li><a class="dropdown-item" href="#">Another action</a></li>
        <li><a class="dropdown-item" href="#">Something else here</a></li>
    </ul>
</div>
`;
  addFromRawHtml(ast.childNodes, typographyHtml);
}

const checks = defineAdderChecks({
  options
});

var index = defineAdder(adder, checks, tests);

export { index as default };
//# sourceMappingURL=index.js.map
